==> esbuild-plugin-scriptable-0.6.2.tgz: package/src/utils.ts <==
import {existsSync, realpathSync} from 'fs';
import {readFile} from 'fs/promises';
import micromatch from 'micromatch';
import path, {resolve} from 'path';

/**
 * Creates a file pattern matcher function
 * @param patterns -Glob patterns to match files
 * @returns A function that returns true if the file matches the patterns
 */
export function createPatternMatcher(patterns?: string | string[]) {
  if (!patterns || (Array.isArray(patterns) && patterns.length === 0) || patterns === '') {
    return () => true;
  }

  return (fileName: string): boolean => isMatch(fileName, patterns);
}

/**
 * Checks if a file name matches a pattern
 *
 * @param fileName -The file name to check
 * @param pattern -The pattern to match
 * @param options -The options to pass to micromatch
 * @returns True if the file name matches the pattern
 */
export function isMatch(fileName: string, pattern: string | readonly string[], options?: micromatch.Options): boolean {
  // Convert to absolute path and normalize
  const absoluteFilePath = path.resolve(fileName);
  const normalizedFilePath = path.relative(process.cwd(), absoluteFilePath).replace(/\\/g, '/');

  const baseOptions = {dot: true, bash: true, basename: true, ...options};

  // Handle array patterns
  if (Array.isArray(pattern)) {
    const positivePatterns = pattern.filter(p => !p.startsWith('!'));
    const negativePatterns = pattern.filter(p => p.startsWith('!')).map(p => p.slice(1));

    const positiveMatch =
      positivePatterns.length === 0 || micromatch.isMatch(normalizedFilePath, positivePatterns, baseOptions);

    const negativeMatch =
      negativePatterns.length > 0 && micromatch.isMatch(normalizedFilePath, negativePatterns, baseOptions);

    return positiveMatch && !negativeMatch;
  }

  // Single pattern match
  return micromatch.isMatch(normalizedFilePath, pattern, baseOptions);
}

// Delayed file check function
export async function waitForFile(filePath: string, timeout = 5000): Promise<void> {
  const start = Date.now();
  while (Date.now() - start < timeout)
    if (existsSync(filePath)) {
      try {
        await readFile(filePath, 'utf-8'); // Check if file is readable

        return; // If the file is readable, exit the loop
      } catch {
        await new Promise(resolve => setTimeout(resolve, 100)); // Try again after a delay
      }
    }
  throw new Error(`File not available after ${timeout}ms: ${filePath}`);
}

export function normalizePath(p: string, resolve = false): string {
  const resolved = resolve ? realpathSync(path.resolve(p)) : p;

  return resolved.replace(/\\/g, '/');
}

export function normalizeAndResolvePath(p: string): string {
  return normalizePath(resolve(p), true);
}

export const np = normalizePath;

export function isPathEqual(path1: string, path2: string): boolean {
  return resolve(normalizePath(path1)) === resolve(normalizePath(path2));
}

==> esbuild-plugin-scriptable-0.6.6.tgz: package/src/utils.ts <==
import {existsSync, realpathSync} from 'fs';
import {readFile} from 'fs/promises';
import micromatch from 'micromatch';
import path, {resolve} from 'path';

/**
 * Creates a file pattern matcher function
 * @param patterns -Glob patterns to match files
 * @returns A function that returns true if the file matches the patterns
 */
export function createPatternMatcher(patterns?: string | string[]) {
  if (!patterns || (Array.isArray(patterns) && patterns.length === 0) || patterns === '') {
    return () => true;
  }

  return (fileName: string): boolean => isMatch(fileName, patterns);
}

/**
 * Checks if a file name matches a pattern
 *
 * @param fileName -The file name to check
 * @param pattern -The pattern to match
 * @param options -The options to pass to micromatch
 * @returns True if the file name matches the pattern
 */
export function isMatch(fileName: string, pattern: string | readonly string[], options?: micromatch.Options): boolean {
  // Convert to absolute path and normalize
  const absoluteFilePath = path.resolve(fileName);
  const normalizedFilePath = path.relative(process.cwd(), absoluteFilePath).replace(/\\/g, '/');

  const baseOptions = {dot: true, bash: true, basename: true, ...options};

  // Handle array patterns
  if (Array.isArray(pattern)) {
    const positivePatterns = pattern.filter(p => !p.startsWith('!'));
    const negativePatterns = pattern.filter(p => p.startsWith('!')).map(p => p.slice(1));

    const positiveMatch =
      positivePatterns.length === 0 || micromatch.isMatch(normalizedFilePath, positivePatterns, baseOptions);

    const negativeMatch =
      negativePatterns.length > 0 && micromatch.isMatch(normalizedFilePath, negativePatterns, baseOptions);

    return positiveMatch && !negativeMatch;
  }

  // Single pattern match
  return micromatch.isMatch(normalizedFilePath, pattern, baseOptions);
}

// Delayed file check function
export async function waitForFile(filePath: string, timeout = 5000): Promise<void> {
  const start = Date.now();
  while (Date.now() - start < timeout)
    if (existsSync(filePath)) {
      try {
        await readFile(filePath, 'utf-8'); // Check if file is readable

        return; // If the file is readable, exit the loop
      } catch {
        await new Promise(resolve => setTimeout(resolve, 100)); // Try again after a delay
      }
    }
  throw new Error(`File not available after ${timeout}ms: ${filePath}`);
}

export function normalizePath(p: string, shouldResolve = false): string {
  // Only use realpathSync if the path exists and needs to be resolved
  const resolved = shouldResolve && existsSync(p) ? realpathSync(path.resolve(p)) : p;

  return resolved.replace(/\\/g, '/');
}

export function normalizeAndResolvePath(p: string): string {
  return normalizePath(resolve(p), true);
}

export const np = normalizePath;

export function isPathEqual(path1: string, path2: string): boolean {
  return resolve(normalizePath(path1)) === resolve(normalizePath(path2));
}
